/*******************************************************************************
 * Copyright (c) 2010 Torsten Zesch.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * Contributors:
 *     Torsten Zesch - initial API and implementation
 ******************************************************************************/
package de.tudarmstadt.ukp.wikipedia.api;

public interface WikiConstants {
    /**
     * Shortcut for System.getProperty("line.separator").
     */
    public static final String LF = System.getProperty("line.separator");

    /**
     * The prefix that is added to page titles of discussion pages
     * Has to be the same as in wikipedia.datamachine:SingleDumpVersionJDKGeneric
     */
    public static final String DISCUSSION_PREFIX = "Discussion:";

    /**
     * Configuration file for the Sweble parser
     */
    public static final String SWEBLE_CONFIG = "classpath:/org/sweble/wikitext/engine/SimpleWikiConfiguration.xml";

    /**
     * Enumerates the languages for which Wikipedia APIs are available.
     * A Wikipedia object can be created using one of these languages.
     */
    // Languages should be lowercase and match the corresponding snowball stemmer names.
    public enum Language {
        abkhazian,
        afar,
        afrikaans,
        akan,
        albanian,
        alemannic,
        amharic,
        anglo_saxon,
        arabic,
        aragonese,
        armenian,
        aromanian,
        assamese,
        assyrian_neo_aramaic,
        asturian,
        avar,
        aymara,
        azeri,
        bambara,
        banyumasan,
        bashkir,
        basque,
        bavarian,
        belarusian,
        belarusian_tarashkevitsa,
        bengali,
        bihari,
        bishnupriya_manipuri,
        bislama,
        bosnian,
        breton,
        buginese,
        bulgarian,
        burmese,
        buryat_russia,
        cantonese,
        catalan,
        cebuano,
        central_bicolano,
        chamorro,
        chechen,
        cherokee,
        cheyenne,
        chichewa,
        chinese,
        choctaw,
        chuvash,
        classical_chinese,
        cornish,
        corsican,
        cree,
        crimean_tatar,
        croatian,
        czech,
        danish,
        divehi,
        dutch,
        dutch_low_saxon,
        dzongkha,
        emilian_romagnol,
        english,
        esperanto,
        estonian,
        ewe,
        faroese,
        fijian,
        finnish,
        franco_provencal_arpitan,
        french,
        friulian,
        fula,
        galician,
        georgian,
        german,
        gilaki,
        gothic,
        greek,
        greenlandic,
        guarani,
        gujarati,
        haitian,
        hakka,
        hausa,
        hawaiian,
        hebrew,
        herero,
        hindi,
        hiri_motu,
        hungarian,
        icelandic,
        ido,
        igbo,
        ilokano,
        indonesian,
        interlingua,
        interlingue,
        inuktitut,
        inupiak,
        irish,
        italian,
        japanese,
        javanese,
        kabyle,
        kalmyk,
        kannada,
        kanuri,
        kapampangan,
        kashmiri,
        kashubian,
        kazakh,
        khmer,
        kikuyu,
        kinyarwanda,
        kirghiz,
        kirundi,
        klingon,
        komi,
        kongo,
        korean,
        kuanyama,
        kurdish,
        ladino,
        lak,
        lao,
        latin,
        latvian,
        ligurian,
        limburgian,
        lingala,
        lithuanian,
        lojban,
        lombard,
        low_saxon,
        lower_sorbian,
        luganda,
        luxembourgish,
        macedonian,
        malagasy,
        malay,
        malayalam,
        maltese,
        manx,
        maori,
        marathi,
        marshallese,
        mazandarani,
        min_dong,
        min_nan,
        moldovan,
        mongolian,
        muscogee,
        nahuatl,
        nauruan,
        navajo,
        ndonga,
        neapolitan,
        nepali,
        newar_nepal_bhasa,
        norfolk,
        norman,
        northern_sami,
        norwegian_bokmal,
        norwegian_nynorsk,
        novial,
        occitan,
        old_church_slavonic,
        oriya,
        oromo,
        ossetian,
        pali,
        pangasinan,
        papiamentu,
        pashto,
        pennsylvania_german,
        persian,
        piedmontese,
        polish,
        portuguese,
        punjabi,
        quechua,
        ripuarian,
        romani,
        romanian,
        romansh,
        russian,
        samoan,
        samogitian,
        sango,
        sanskrit,
        sardinian,
        saterland_frisian,
        scots,
        scottish_gaelic,
        serbian,
        serbo_croatian,
        sesotho,
        shona,
        sichuan_yi,
        sicilian,
        simple_english,
        sindhi,
        sinhalese,
        slovak,
        slovenian,
        somali,
        spanish,
        sundanese,
        swahili,
        swati,
        swedish,
        tagalog,
        tahitian,
        tajik,
        tamil,
        tarantino,
        tatar,
        telugu,
        tetum,
        thai,
        tibetan,
        tigrinya,
        tok_pisin,
        tokipona,
        tongan,
        tsonga,
        tswana,
        tumbuka,
        turkish,
        turkmen,
        twi,
        udmurt,
        ukrainian,
        upper_sorbian,
        urdu,
        uyghur,
        uzbek,
        venda,
        venetian,
        vietnamese,
        volapuek,
        voro,
        walloon,
        waray_waray,
        welsh,
        west_flemish,
        west_frisian,
        wolof,
        wu,
        xhosa,
        yiddish,
        yoruba,
        zamboanga_chavacano,
        zazaki,
        zealandic,
        zhuang,
        zulu,
        _test
    }
}
